==> quasar-1.7.1.jar: META-INF/resources/webjars/quasar/1.7.1/icon-set/fontawesome-v5.js <==
export default {
  name: 'fontawesome-v5',
  type: {
    positive: 'fas fa-check',
    negative: 'fas fa-exclamation-triangle',
    info: 'fas fa-info-circle',
    warning: 'fas fa-exclamation'
  },
  arrow: {
    up: 'fas fa-arrow-up',
    right: 'fas fa-arrow-right',
    down: 'fas fa-arrow-down',
    left: 'fas fa-arrow-left',
    dropdown: 'fas fa-caret-down'
  },
  chevron: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },
  colorPicker: {
    spectrum: 'fas fa-eye-dropper',
    tune: 'fas fa-sliders-h',
    palette: 'fas fa-swatchbook'
  },
  pullToRefresh: {
    icon: 'fas fa-sync-alt'
  },
  carousel: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right', // TODO
    navigationIcon: 'fas fa-circle',
    thumbnails: 'fas fa-th'
  },
  chip: {
    remove: 'fas fa-times-circle',
    selected: 'fas fa-check'
  },
  datetime: {
    arrowLeft: 'fas fa-chevron-left',
    arrowRight: 'fas fa-chevron-right',
    now: 'far fa-clock',
    today: 'far fa-calendar-check'
  },
  editor: {
    bold: 'fas fa-bold',
    italic: 'fas fa-italic',
    strikethrough: 'fas fa-strikethrough',
    underline: 'fas fa-underline',
    unorderedList: 'fas fa-list-ul',
    orderedList: 'fas fa-list-ol',
    subscript: 'fas fa-subscript',
    superscript: 'fas fa-superscript',
    hyperlink: 'fas fa-link',
    toggleFullscreen: 'fas fa-expand-arrows-alt',
    quote: 'fas fa-quote-right',
    left: 'fas fa-align-left',
    center: 'fas fa-align-center',
    right: 'fas fa-align-right',
    justify: 'fas fa-align-justify',
    print: 'fas fa-print',
    outdent: 'fas fa-outdent',
    indent: 'fas fa-indent',
    removeFormat: 'fas fa-eraser',
    formatting: 'fas fa-heading',
    fontSize: 'fas fa-text-height',
    align: 'fas fa-align-left',
    hr: 'far fa-minus-square',
    undo: 'fas fa-undo',
    redo: 'fas fa-redo',
    heading: 'fas fa-heading',
    code: 'fas fa-code',
    size: 'fas fa-text-height',
    font: 'fas fa-font',
    viewSource: 'fas fa-code'
  },
  expansionItem: {
    icon: 'fas fa-chevron-down',
    denseIcon: 'fas fa-caret-down'
  },
  fab: {
    icon: 'fas fa-plus',
    activeIcon: 'fas fa-times'
  },
  field: {
    clear: 'fas fa-times-circle',
    error: 'fas fa-exclamation-circle'
  },
  pagination: {
    first: 'fas fa-step-backward',
    prev: 'fas fa-chevron-left',
    next: 'fas fa-chevron-right',
    last: 'fas fa-step-forward'
  },
  rating: {
    icon: 'fas fa-star'
  },
  stepper: {
    done: 'fas fa-check',
    active: 'fas fa-pencil-alt',
    error: 'fas fa-exclamation-triangle'
  },
  tabs: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right',
    up: 'fas fa-chevron-up',
    down: 'fas fa-chevron-down'
  },
  table: {
    arrowUp: 'fas fa-arrow-up',
    warning: 'fas fa-exclamation-triangle',
    prevPage: 'fas fa-chevron-left',
    nextPage: 'fas fa-chevron-right'
  },
  tree: {
    icon: 'fas fa-play'
  },
  uploader: {
    done: 'fas fa-check',
    clear: 'fas fa-times',
    add: 'fas fa-plus-square',
    upload: 'fas fa-upload',
    removeQueue: 'fas fa-stream',
    removeUploaded: 'fas fa-clipboard-check'
  }
}

==> quasar-1.9.15.jar: META-INF/resources/webjars/quasar/1.9.15/icon-set/fontawesome-v5.js <==
export default {
  name: 'fontawesome-v5',
  type: {
    positive: 'fas fa-check',
    negative: 'fas fa-exclamation-triangle',
    info: 'fas fa-info-circle',
    warning: 'fas fa-exclamation'
  },
  arrow: {
    up: 'fas fa-arrow-up',
    right: 'fas fa-arrow-right',
    down: 'fas fa-arrow-down',
    left: 'fas fa-arrow-left',
    dropdown: 'fas fa-caret-down'
  },
  chevron: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },
  colorPicker: {
    spectrum: 'fas fa-eye-dropper',
    tune: 'fas fa-sliders-h',
    palette: 'fas fa-swatchbook'
  },
  pullToRefresh: {
    icon: 'fas fa-sync-alt'
  },
  carousel: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right', // TODO
    up: 'fas fa-chevron-up',
    down: 'fas fa-chevron-down',
    navigationIcon: 'fas fa-circle'
  },
  chip: {
    remove: 'fas fa-times-circle',
    selected: 'fas fa-check'
  },
  datetime: {
    arrowLeft: 'fas fa-chevron-left',
    arrowRight: 'fas fa-chevron-right',
    now: 'far fa-clock',
    today: 'far fa-calendar-check'
  },
  editor: {
    bold: 'fas fa-bold',
    italic: 'fas fa-italic',
    strikethrough: 'fas fa-strikethrough',
    underline: 'fas fa-underline',
    unorderedList: 'fas fa-list-ul',
    orderedList: 'fas fa-list-ol',
    subscript: 'fas fa-subscript',
    superscript: 'fas fa-superscript',
    hyperlink: 'fas fa-link',
    toggleFullscreen: 'fas fa-expand-arrows-alt',
    quote: 'fas fa-quote-right',
    left: 'fas fa-align-left',
    center: 'fas fa-align-center',
    right: 'fas fa-align-right',
    justify: 'fas fa-align-justify',
    print: 'fas fa-print',
    outdent: 'fas fa-outdent',
    indent: 'fas fa-indent',
    removeFormat: 'fas fa-eraser',
    formatting: 'fas fa-heading',
    fontSize: 'fas fa-text-height',
    align: 'fas fa-align-left',
    hr: 'far fa-minus-square',
    undo: 'fas fa-undo',
    redo: 'fas fa-redo',
    heading: 'fas fa-heading',
    code: 'fas fa-code',
    size: 'fas fa-text-height',
    font: 'fas fa-font',
    viewSource: 'fas fa-code'
  },
  expansionItem: {
    icon: 'fas fa-chevron-down',
    denseIcon: 'fas fa-caret-down'
  },
  fab: {
    icon: 'fas fa-plus',
    activeIcon: 'fas fa-times'
  },
  field: {
    clear: 'fas fa-times-circle',
    error: 'fas fa-exclamation-circle'
  },
  pagination: {
    first: 'fas fa-step-backward',
    prev: 'fas fa-chevron-left',
    next: 'fas fa-chevron-right',
    last: 'fas fa-step-forward'
  },
  rating: {
    icon: 'fas fa-star'
  },
  stepper: {
    done: 'fas fa-check',
    active: 'fas fa-pencil-alt',
    error: 'fas fa-exclamation-triangle'
  },
  tabs: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right',
    up: 'fas fa-chevron-up',
    down: 'fas fa-chevron-down'
  },
  table: {
    arrowUp: 'fas fa-arrow-up',
    warning: 'fas fa-exclamation-triangle',
    prevPage: 'fas fa-chevron-left',
    nextPage: 'fas fa-chevron-right'
  },
  tree: {
    icon: 'fas fa-play'
  },
  uploader: {
    done: 'fas fa-check',
    clear: 'fas fa-times',
    add: 'fas fa-plus-square',
    upload: 'fas fa-upload',
    removeQueue: 'fas fa-stream',
    removeUploaded: 'fas fa-clipboard-check'
  }
}
